==> angular-iscroll-3.2.0.jar: META-INF/resources/webjars/angular-iscroll/3.2.0/CHANGELOG.md <==
# Change Log

## [v3.2.0](https://github.com/mtr/angular-iscroll/tree/v3.2.0) (2016-01-27)
[Full Changelog](https://github.com/mtr/angular-iscroll/compare/v3.1.0...v3.2.0)

**Merged pull requests:**

- \#25 Add platform.js requirement to bower.json [\#27](https://github.com/mtr/angular-iscroll/pull/27) ([simison](https://github.com/simison))

## [v3.1.0](https://github.com/mtr/angular-iscroll/tree/v3.1.0) (2016-01-22)
[Full Changelog](https://github.com/mtr/angular-iscroll/compare/v3.0.0...v3.1.0)

## [v3.0.0](https://github.com/mtr/angular-iscroll/tree/v3.0.0) (2016-01-22)
[Full Changelog](https://github.com/mtr/angular-iscroll/compare/v2.0.1...v3.0.0)

**Implemented enhancements:**

- Automatically detect the need for using iScroll. [\#25](https://github.com/mtr/angular-iscroll/issues/25)
- Support being initially disabled. [\#24](https://github.com/mtr/angular-iscroll/issues/24)
- Address jshint issues [\#23](https://github.com/mtr/angular-iscroll/issues/23)
- Remove unmaintained example code because core-layout is well maintained [\#22](https://github.com/mtr/angular-iscroll/issues/22)
- Add bitHound configuration. [\#21](https://github.com/mtr/angular-iscroll/issues/21)
- Address npm dependency issues found in master branch \[Opened by bitHound\] [\#20](https://github.com/mtr/angular-iscroll/issues/20)

**Fixed bugs:**

- iScrollServiceProvider.configureDefaults\(\) does not perform a deep merge of options with defaultOptions. [\#26](https://github.com/mtr/angular-iscroll/issues/26)

## [v2.0.1](https://github.com/mtr/angular-iscroll/tree/v2.0.1) (2015-12-17)
[Full Changelog](https://github.com/mtr/angular-iscroll/compare/v2.0.0...v2.0.1)

## [v2.0.0](https://github.com/mtr/angular-iscroll/tree/v2.0.0) (2015-12-16)
[Full Changelog](https://github.com/mtr/angular-iscroll/compare/v1.3.3...v2.0.0)

**Merged pull requests:**

- Add option to skip digest cycle when refresh option is turned on [\#19](https://github.com/mtr/angular-iscroll/pull/19) ([DinkoMiletic](https://github.com/DinkoMiletic))

## [v1.3.3](https://github.com/mtr/angular-iscroll/tree/v1.3.3) (2015-06-07)
[Full Changelog](https://github.com/mtr/angular-iscroll/compare/v1.3.2...v1.3.3)

**Implemented enhancements:**

- Create simple configuration interface for defining event handlers. [\#10](https://github.com/mtr/angular-iscroll/issues/10)

**Merged pull requests:**

- Adds bower.json and bower install instructions [\#12](https://github.com/mtr/angular-iscroll/pull/12) ([savelbr](https://github.com/savelbr))

## [v1.3.2](https://github.com/mtr/angular-iscroll/tree/v1.3.2) (2015-05-23)
[Full Changelog](https://github.com/mtr/angular-iscroll/compare/v1.3.1...v1.3.2)

## [v1.3.1](https://github.com/mtr/angular-iscroll/tree/v1.3.1) (2015-05-23)
[Full Changelog](https://github.com/mtr/angular-iscroll/compare/v1.3.0...v1.3.1)

## [v1.3.0](https://github.com/mtr/angular-iscroll/tree/v1.3.0) (2015-05-23)
[Full Changelog](https://github.com/mtr/angular-iscroll/compare/v1.2.5...v1.3.0)

## [v1.2.5](https://github.com/mtr/angular-iscroll/tree/v1.2.5) (2015-05-23)
[Full Changelog](https://github.com/mtr/angular-iscroll/compare/v1.2.4...v1.2.5)

**Merged pull requests:**

- Add a Bitdeli Badge to README [\#9](https://github.com/mtr/angular-iscroll/pull/9) ([bitdeli-chef](https://github.com/bitdeli-chef))

## [v1.2.4](https://github.com/mtr/angular-iscroll/tree/v1.2.4) (2015-03-25)
[Full Changelog](https://github.com/mtr/angular-iscroll/compare/v1.2.3...v1.2.4)

**Fixed bugs:**

- Interval is not being closed after destroying instance of angular-iscroll [\#6](https://github.com/mtr/angular-iscroll/issues/6)

**Merged pull requests:**

- Cancelling intervals when destroying instance [\#7](https://github.com/mtr/angular-iscroll/pull/7) ([wkwiatek](https://github.com/wkwiatek))

## [v1.2.3](https://github.com/mtr/angular-iscroll/tree/v1.2.3) (2015-03-05)
[Full Changelog](https://github.com/mtr/angular-iscroll/compare/v1.2.2...v1.2.3)

## [v1.2.2](https://github.com/mtr/angular-iscroll/tree/v1.2.2) (2015-02-25)
[Full Changelog](https://github.com/mtr/angular-iscroll/compare/v1.2.1...v1.2.2)

**Implemented enhancements:**

- Documentation [\#4](https://github.com/mtr/angular-iscroll/issues/4)

## [v1.2.1](https://github.com/mtr/angular-iscroll/tree/v1.2.1) (2015-02-24)
[Full Changelog](https://github.com/mtr/angular-iscroll/compare/v1.2.0...v1.2.1)

## [v1.2.0](https://github.com/mtr/angular-iscroll/tree/v1.2.0) (2015-02-15)
[Full Changelog](https://github.com/mtr/angular-iscroll/compare/v1.1.2...v1.2.0)

**Implemented enhancements:**

- Support configuring the default options during myApp.config\(\) [\#3](https://github.com/mtr/angular-iscroll/issues/3)

## [v1.1.2](https://github.com/mtr/angular-iscroll/tree/v1.1.2) (2015-02-07)
[Full Changelog](https://github.com/mtr/angular-iscroll/compare/v1.1.1...v1.1.2)

**Fixed bugs:**

- Declare Sass variables as defaults, so they can easily be overridden. [\#2](https://github.com/mtr/angular-iscroll/issues/2)

## [v1.1.1](https://github.com/mtr/angular-iscroll/tree/v1.1.1) (2015-02-06)
[Full Changelog](https://github.com/mtr/angular-iscroll/compare/v1.1.0...v1.1.1)

## [v1.1.0](https://github.com/mtr/angular-iscroll/tree/v1.1.0) (2015-02-06)
[Full Changelog](https://github.com/mtr/angular-iscroll/compare/v1.0.0...v1.1.0)

**Implemented enhancements:**

- Add support for periodic instance.refresh\(\) calls. [\#1](https://github.com/mtr/angular-iscroll/issues/1)

## [v1.0.0](https://github.com/mtr/angular-iscroll/tree/v1.0.0) (2015-02-05)


\* *This Change Log was automatically generated by [github_changelog_generator](https://github.com/skywinder/Github-Changelog-Generator)*

==> angular-iscroll-3.5.1.jar: META-INF/resources/webjars/angular-iscroll/3.5.1/CHANGELOG.md <==
# Change Log

## [v3.4.0](https://github.com/mtr/angular-iscroll/tree/v3.4.0) (2016-09-02)
[Full Changelog](https://github.com/mtr/angular-iscroll/compare/v3.2.0...v3.4.0)

**Implemented enhancements:**

- Refine the need-iScroll auto-detection rules [\#28](https://github.com/mtr/angular-iscroll/issues/28)

## [v3.2.0](https://github.com/mtr/angular-iscroll/tree/v3.2.0) (2016-01-27)
[Full Changelog](https://github.com/mtr/angular-iscroll/compare/v3.1.0...v3.2.0)

**Merged pull requests:**

- \#25 Add platform.js requirement to bower.json [\#27](https://github.com/mtr/angular-iscroll/pull/27) ([simison](https://github.com/simison))

## [v3.1.0](https://github.com/mtr/angular-iscroll/tree/v3.1.0) (2016-01-22)
[Full Changelog](https://github.com/mtr/angular-iscroll/compare/v3.0.0...v3.1.0)

## [v3.0.0](https://github.com/mtr/angular-iscroll/tree/v3.0.0) (2016-01-22)
[Full Changelog](https://github.com/mtr/angular-iscroll/compare/v2.0.1...v3.0.0)

**Implemented enhancements:**

- Automatically detect the need for using iScroll. [\#25](https://github.com/mtr/angular-iscroll/issues/25)
- Support being initially disabled. [\#24](https://github.com/mtr/angular-iscroll/issues/24)
- Address jshint issues [\#23](https://github.com/mtr/angular-iscroll/issues/23)
- Remove unmaintained example code because core-layout is well maintained [\#22](https://github.com/mtr/angular-iscroll/issues/22)
- Add bitHound configuration. [\#21](https://github.com/mtr/angular-iscroll/issues/21)
- Address npm dependency issues found in master branch \[Opened by bitHound\] [\#20](https://github.com/mtr/angular-iscroll/issues/20)

**Fixed bugs:**

- iScrollServiceProvider.configureDefaults\(\) does not perform a deep merge of options with defaultOptions. [\#26](https://github.com/mtr/angular-iscroll/issues/26)

## [v2.0.1](https://github.com/mtr/angular-iscroll/tree/v2.0.1) (2015-12-17)
[Full Changelog](https://github.com/mtr/angular-iscroll/compare/v2.0.0...v2.0.1)

## [v2.0.0](https://github.com/mtr/angular-iscroll/tree/v2.0.0) (2015-12-16)
[Full Changelog](https://github.com/mtr/angular-iscroll/compare/v1.3.3...v2.0.0)

**Merged pull requests:**

- Add option to skip digest cycle when refresh option is turned on [\#19](https://github.com/mtr/angular-iscroll/pull/19) ([DinkoMiletic](https://github.com/DinkoMiletic))
- Fixing bug where the argument passed to configureDefaults\(\) clobbers the built-in defaults [\#17](https://github.com/mtr/angular-iscroll/pull/17) ([mikechamberlain](https://github.com/mikechamberlain))

## [v1.3.3](https://github.com/mtr/angular-iscroll/tree/v1.3.3) (2015-06-07)
[Full Changelog](https://github.com/mtr/angular-iscroll/compare/v1.3.2...v1.3.3)

**Implemented enhancements:**

- Create simple configuration interface for defining event handlers. [\#10](https://github.com/mtr/angular-iscroll/issues/10)

**Merged pull requests:**

- Adds bower.json and bower install instructions [\#12](https://github.com/mtr/angular-iscroll/pull/12) ([savelbr](https://github.com/savelbr))

## [v1.3.2](https://github.com/mtr/angular-iscroll/tree/v1.3.2) (2015-05-23)
[Full Changelog](https://github.com/mtr/angular-iscroll/compare/v1.3.1...v1.3.2)

## [v1.3.1](https://github.com/mtr/angular-iscroll/tree/v1.3.1) (2015-05-23)
[Full Changelog](https://github.com/mtr/angular-iscroll/compare/v1.3.0...v1.3.1)

## [v1.3.0](https://github.com/mtr/angular-iscroll/tree/v1.3.0) (2015-05-23)
[Full Changelog](https://github.com/mtr/angular-iscroll/compare/v1.2.5...v1.3.0)

## [v1.2.5](https://github.com/mtr/angular-iscroll/tree/v1.2.5) (2015-05-23)
[Full Changelog](https://github.com/mtr/angular-iscroll/compare/v1.2.4...v1.2.5)

**Merged pull requests:**

- Add a Bitdeli Badge to README [\#9](https://github.com/mtr/angular-iscroll/pull/9) ([bitdeli-chef](https://github.com/bitdeli-chef))

## [v1.2.4](https://github.com/mtr/angular-iscroll/tree/v1.2.4) (2015-03-25)
[Full Changelog](https://github.com/mtr/angular-iscroll/compare/v1.2.3...v1.2.4)

**Fixed bugs:**

- Interval is not being closed after destroying instance of angular-iscroll [\#6](https://github.com/mtr/angular-iscroll/issues/6)

**Merged pull requests:**

- Cancelling intervals when destroying instance [\#7](https://github.com/mtr/angular-iscroll/pull/7) ([wkwiatek](https://github.com/wkwiatek))

## [v1.2.3](https://github.com/mtr/angular-iscroll/tree/v1.2.3) (2015-03-05)
[Full Changelog](https://github.com/mtr/angular-iscroll/compare/v1.2.2...v1.2.3)

## [v1.2.2](https://github.com/mtr/angular-iscroll/tree/v1.2.2) (2015-02-25)
[Full Changelog](https://github.com/mtr/angular-iscroll/compare/v1.2.1...v1.2.2)

**Implemented enhancements:**

- Documentation [\#4](https://github.com/mtr/angular-iscroll/issues/4)

## [v1.2.1](https://github.com/mtr/angular-iscroll/tree/v1.2.1) (2015-02-24)
[Full Changelog](https://github.com/mtr/angular-iscroll/compare/v1.2.0...v1.2.1)

## [v1.2.0](https://github.com/mtr/angular-iscroll/tree/v1.2.0) (2015-02-15)
[Full Changelog](https://github.com/mtr/angular-iscroll/compare/v1.1.2...v1.2.0)

**Implemented enhancements:**

- Support configuring the default options during myApp.config\(\) [\#3](https://github.com/mtr/angular-iscroll/issues/3)

## [v1.1.2](https://github.com/mtr/angular-iscroll/tree/v1.1.2) (2015-02-07)
[Full Changelog](https://github.com/mtr/angular-iscroll/compare/v1.1.1...v1.1.2)

**Fixed bugs:**

- Declare Sass variables as defaults, so they can easily be overridden. [\#2](https://github.com/mtr/angular-iscroll/issues/2)

## [v1.1.1](https://github.com/mtr/angular-iscroll/tree/v1.1.1) (2015-02-06)
[Full Changelog](https://github.com/mtr/angular-iscroll/compare/v1.1.0...v1.1.1)

## [v1.1.0](https://github.com/mtr/angular-iscroll/tree/v1.1.0) (2015-02-06)
[Full Changelog](https://github.com/mtr/angular-iscroll/compare/v1.0.0...v1.1.0)

**Implemented enhancements:**

- Add support for periodic instance.refresh\(\) calls. [\#1](https://github.com/mtr/angular-iscroll/issues/1)

## [v1.0.0](https://github.com/mtr/angular-iscroll/tree/v1.0.0) (2015-02-05)


\* *This Change Log was automatically generated by [github_changelog_generator](https://github.com/skywinder/Github-Changelog-Generator)*
